/***********************************************/
/*               E S A W - DATA                */
/***********************************************/
/* Data til ESAW                               */
/* Anders Christensen, 17.06.2022              */
/* Rev. SAS-program                            */
/* Jens Mondrup       - data 1997              */
/* Mia Bracht Nielsen - data 1998, 2000,       */
/* Anders Christensen - data 2001, 2002, 2003, */
/*   2004, 2005, 2006, 2007, 2008, 2010, 2011, */
/*   2012, 2013, 2014, 2015, 2016, 2017, 2018, */
/*   2019, 2020, 2021                          */
/***********************************************/
libname library "&baseFolder.\specRegistre\STATREG\UT_TEST\UTdata\Fmtbib_ut0615";
libname ach "\\at-sasmetap1\data\abs\work\Anders";
%let udata = abswork.ut1322_b_final;

/******************************************************/
/* IMPORT AF DATA 2020 FRA LUFTFARTEN  (AIR)          */
/* Data modtaget fra Trafikst. som Word-fil:   10 obs.*/
/******************************************************/
/* IMPORT AF DATA 2020 FRA OFF SHORE    (OFF)         */
/* Data modtaget fra ON som Excel-fil:          9 obs.*/
/******************************************************/
/* IMPORT AF DATA 2020 FRA SFARTEN     (DMA)         */
/* Data modtaget fra SS som Excel-fil:       155 obs.*/
/******************************************************/
data import; /* 174 obs */
set samleark_SOL; /* Proc import fra Excel */
length aldr $2 br $6 ;
utid = substr(utid_t,1,5);
/*if substr(utid,3,2) = '::' then utid_t = substr(utid,1,3)||'00';
if substr(utid,5,1) = ':'  then utid_t = substr(utid,1,4)||'0';
if utid = '3:00' then utid_t = '03:00';*/
job4_e5 = substr(disc,1,4);
aldr = alder; if alder in ('221', '222') then aldr = '22'; if alder = '-939' then aldr = '.';
utdd = utdd_n;
kon = kqn;
if kqn = '1' then kon = 'M';
if kqn = '2' then kon = 'K';
if kqn = '9' then kon = '';
lbnreasy_num = lbnreasy*1;
p_br = br; if br = '500000' then p_br = '501000';
drop utid_t utdd_n disc alder region lbnreasy; 
run;
data ach.import_2021; set import; 
utid_t = utid;
br = p_br; 
kqn = kon;
drop p_br utid kon; run;

/******************************************************/
/***********************************************/
/* Udtrk af rets data st: AT                */
/***********************************************/
data ut; /* 45.688 obs */
set &udata;
if lbnreasy in ('12523744', '12529775')then p_br = '471900';
if lbnreasy in ('12523744', '12529775')then p_br36 = '04';
if utar4 = '2021'       		 /* Referenceaar er 2021 */
and foel_e5 not in ('01', '02'); /* Ulykken skal have givet mere end 3 dages fravaer */
aut = 'wea';          			 /* Arbejdstilsynets omrde */
tekn = '';
lbnreasy_num = lbnreasy*1;
keep lbnreasy_num p_br job4_e5 aldr kqn foel_e5 skda2_e5 lgmd2_e5 sbsk p_antal_ansatte 
     usted_e5 us_kommune_nr utdd utid_t anfo2_e5 afv2_e5 skma2_e5 tekn aut cov covid_status;
run;
proc sort data=ut; by lbnreasy_num; run;

data ach.at_2021; set ut;  /* 45.688 obs */
length br $6;
region_n = us_kommune_nr;
br = p_br;
utid = substr(utid_t,1,5);
drop us_kommune_nr p_br;
run;

data ach.esaw_2021;      /* 45.908 obs */
 set	ach.at_2021      /* 45.688 obs */
		ach.import_2021; /*    220 obs */
run;

proc sort data=ach.esaw_2021; by utdd; run;
proc contents data=esaw_2020; run;
title1 'Table 1: Anmeldte arbejdsulykker 2020';
title2 '         fordelt p ';
%X2
(esaw_2020, "Skademde" , "Myndighed", internal ,
usted_e5, aut, $usted_e5_ , $ , 30.0 , 6.0 , 7.0 , noseps , 62 , 109);

/***********************************************/
/*         O M K O D N I N G E R  mv.          */
/* Variabler der indberettes til ESAW fase 1-3 */
/* evt. efter omkodning til ny terminologi     */
/***********************************************/
data esaw_2021_DK;
set ach.esaw_2021 (obs=45908);
length case $11 nace $4 isco $2 age $2 sex $1 inj $3 body $2 geo $5 
       date 8. time $2 size $1 nati $1 empst $3 sev $3 wst $1 wen $3 
       wpr $2 spa $2 ma_spa $4 dev $2 ma_dev $4 cmi $2 ma_cmi $4 rta $1 wgt 3. wgt_dev 3. wgt_ma_cmi 3.;
label	case   = 'Case number'
		nace   = 'Economic activity of the employer'
		isco   = 'Occupation of the victim'
		age    = 'Age of the victim'
		sex    = 'Sex of the victim'
		inj    = 'Type of injury'
		body   = 'Part of body injured'
		geo    = 'Geographical location'
		date   = 'Date of the accident'
		time   = 'Time of the accident'
		size   = 'Size of enterprise ('
		nati   = 'Nationality'
		empst  = 'Employment status'
		sev    = 'Days lost'
		wst    = 'Work station' 
		wen    = 'Working environment' 
		wpr    = 'Working process' 
		spa    = 'Specific physical activity' 
		ma_spa = 'Material agent - activity' 
		dev    = 'Deviation'
		ma_dev = 'Material agent - deviation' 
		cmi    = 'Contact - Mode of injury' 
		ma_cmi = 'Material agent - contact'
		rta    = 'Road trafic accident' 
		wgt    = 'Weight'
		wgt_dev = 'Weight - Deviation'
		wgt_ma_cmi = 'Weight - Material agent - contact';
/***********************************************/
* Case number - phase 1
- Case ($11.)
Generering af loebenummer til Casenumber;
length id 8.;
ID = (_N_ + 1) - 1; /* Primrngle genereres */
if id <= 9 then gab = '000000';
else if 10 <= id <= 99 then gab = '00000';
else if 100 <= id <= 999 then gab = '0000';
else if 1000 <= id <= 9999 then gab = '000';
else if 10000 <= id <= 99999 then gab = '00';
else if 100000 <= id <= 999999 then gab = '0';
else gab = '';
fill = right(gab)||left(id);
case = '2021'||left(fill);

/***********************************************/
* Economic activity of employer - phase 1
- Nace ($4.) (UNK)
Omkodning af Branche til Arbejdsgiverens erhverv (NACE);
nace = substr(br,1,4);
if br in ('999999', '') then nace = 'UNK';

/***********************************************/
* Occupation - phase 1
- Isco ($2.) (UN)
Omkodning af jobgruppe (DISCO_08) til ISCO;
isco = substr(job4_e5,1,2) ;
if job4_e5 in ('9999', 'Uopl', '', '0000') then isco = 'UN';

/***********************************************/
* Age of victim - phase 1
- Age ($2.) (99)
Omkodning af alder p ulykkestidspunktet (ALDR) til AGE;
age = aldr ;
if aldr > '90' then age = '98';
if aldr in ('', '.') then age = '99';

/***********************************************/
* Sex of victim - phase 1
- Sex ($1.) (9)
Omkodning af koen (KQN) til sex (SEX);
if      kqn = 'M' then sex = '1' ;
else if kqn = 'K' then sex = '2' ;
else                   sex = '9' ;

/***********************************************/
* Type of injury - phase 1
- Inj ($3.) (98)
* Ny variabel (SKDA) der svarer til ESAW (INJ) ;
inj = skda2_e5;
if skda2_e5 in ('', '000', '999') then  inj = '000';
if skda2_e5 = '998' then  inj = '999';
if covid_status = 1 then inj = '073';
/***********************************************/
* Part of body injured - phase 1
Body($2.) (00)
Omkodning af skadet legemsdel (SKLD) til Part (BODY);
* Ny variabel (LGMD) der svarer til ESAW (BODY) ;
body = lgmd2_e5;
if lgmd2_e5 = '72' then body = '71';
if lgmd2_e5 in ('', '0', '00', '99') then body = '00';
if lgmd2_e5 = '98' then body = '99';
/***********************************************/
* Geografical location - phase 1
- Geo (@5.) (DKXXX) ;
* omkodning af Region_n til geo (region) - ESAW ;
* Data omfatter kun ulykker, der er sket i DK! ;
* ach 29.06.2010;
 /*if      region_n = 1081 then geo='DK050' ;
   else if region_n = 1082 then geo='DK040' ;
   else if region_n = 1083 then geo='DK030' ;
   else if region_n = 1084 then geo='DK010' ;
   else if region_n = 1085 then geo='DK020' ;
   else if region_n = 7    then geo='DKZZZ' ;
   else                         geo='UNK' ;*/
* ach 26.07.2017 - omkodning fra KOM til NUTS3;
geo = 'DKZZZ';
if region_n in (
101,147,155,185,1084) then geo = 'DK011';
if region_n in (
151,153,157,159,161,163,165,167,169,173,175,183,187) then geo = 'DK012';
if region_n in (
190,201,210,217,219,223,230,240,250,260,270) then geo = 'DK013';
if region_n in (
400,411) then geo = 'DK014';
if region_n in (
253,259,265,269,350) then geo = 'DK021';
if region_n in (
306,316,320,326,329,330,336,340,360,370,376,390, 1085) then geo = 'DK022';
if region_n in (
410,420,430,440,450,461,479,480,482,492) then geo = 'DK031';
if region_n in (
510,530,540,550,561,563,573,575,580,607,621,630,1083) then geo = 'DK032';
if region_n in (
657,661,665,671,756,760,779,791) then geo = 'DK041';
if region_n in (
615,706,707,710,727,730,740,741,746,751,766) then geo = 'DK042';
if region_n in (
773,787,810,813,820,825,840,846,849,851,860) then geo = 'DK050';
if region_n in (0, ., 999) then geo = 'UNK';
/***********************************************/
* Date of accident - phase 1
- Date ($8) (999999);
* datex = datepart(utdd);
*dato = substr(put(datex,yymmdd6.),1,6);
*date = '20'||dato;
*if utdd_n in ( , .) then date=utar4||'0000';
*if utdd = '999999' then date = '00000000';
date = utdd;
if utdd in ('','18992131') then date = '00000000'; 
/***********************************************/
* Time of accident - phase 1
- Time ($2.) (99) ;
* NB: Bruger SAS-afkortning til time ;
/*	 if substr(utid_t,1,2) in ('t0', 't1', 't2')
	 then timenum = substr(utid_t,2,2);
	 else timenum = substr(utid_t,1,2);
     time  = timenum;
     if      timenum = '0:' or
             timenum = '24' then time = '00';
	 else if timenum = '1:' then time = '01';
	 else if timenum = '2:' then time = '02';
	 else if timenum = '3:' then time = '03';
	 else if timenum = '4:' then time = '04';
	 else if timenum = '5:' then time = '05';
	 else if timenum = '6:' then time = '06';
	 else if timenum = '7:' then time = '07';
	 else if timenum = '8:' then time = '08';
	 else if timenum = '9:' then time = '09';
     else if timenum = 'Uo' or
             timenum = ''   then time = '99';*/
time = substr(utid_t,1,2);
if utid_t in ('', 'Uoply') then time = '99';
/***********************************************/ 
* Size of enterprise - phase 2, 1996
- Size ($1.) (9) 
- P_ANTAL_ANSATTE
* %inc omkod(ansatte_size);
size = '9';
if   0.00 le P_ANTAL_ANSATTE le   0.49 then size = '0';
if   0.50 le P_ANTAL_ANSATTE le   9.49 then size = '1';
if   9.50 le P_ANTAL_ANSATTE le  49.49 then size = '2';
if  49.50 le P_ANTAL_ANSATTE le 249.49 then size = '3';
if 249.50 le P_ANTAL_ANSATTE le 499.49 then size = '4';
if 499.49 <  P_ANTAL_ANSATTE           then size = '5';

/***********************************************/
* Nationality - phase 2, 1996
- Nati ($1.) (0);
* nati_naeu.sas ;
* ACH 09.06.2021, rev. til 27 EU-lande: -UK
* omkodning af statsborgerskabsland til EU-klassifikation ;
nati = '3';      /* Statsborger i et land uden for EU */
if sbsk in ('', '0', '5999', '9999')
then nati = '0'; /* Statsborgerskab uoplyst */
if sbsk = '5100' 
then nati = '1'; /* Statsborger i landet: Danmark */
if sbsk in (
'5104', '5108', '5120', '5126', '5130', '5134', '5140', 
'5142', '5150', '5156', '5164', '5180', '5182', '5128', 
'5153', '5154', '5158', '5174', '5422', '5607', 
'5609', '5611', '5750', '5752', '5776', '5778')
then nati = '2'; /* Statsborger i et andet EU-land: EU27 */

/***********************************************/
* Employment status - phase 2, 1996, rev. 2015
- Emps ($3.) (0) ;
* OMKOD: ANFO_EMPS.sas;
/*Erhvervsmssig status uoplyst*/
                                    empst = '000';
/*Selvstndig*/
if anfo2_e5 = '31'             then empst = '100';   
/*Lnmodtager*/
if anfo2_e5 in ('10', '11')    then empst = '300';       
/*Medhjlpende familiemedlem*/    
if anfo2_e5 in ('32', '33')    then empst = '400';
/*Under uddannelse*/
if anfo2_e5 in 
('20', '21', '22', '23', '29') then empst = '500';
/*Anden erhvervsmssig status*/
if anfo2_e5 in 
('41', '42', '43', '44', '49') then empst = '900';

/***********************************************/
* Days Lost - phase 2, 1996
- Sev ($3.) (000) ;
/*Fravr uoplyst*/
                            sev = '000';  /* Uoplyst */
/*Fravr over 4 - 6 dage*/
     if foel_e5 = '03' then sev = 'A01';  /* =4-6 dage */
/*Fravr over 7 - 13 dage*/
else if foel_e5 = '04' then sev = 'A02';  /* =7-13 dage */
/*Forventet fravr 14-20 dage*/
else if foel_e5 = '05' then sev = 'A03';  /* =14-20 dage */
/*Forventet fravr 21 dage til en mned*/
else if foel_e5 = '06' then sev = 'A04';  /* =21-30 dage */
/*Forventet fravr 1 - 3 mneder*/
else if foel_e5 = '07' then sev = 'A05';  /* =1-3 mdr. */
/*Forventet fravr 3 - 6 mneder*/
else if foel_e5 = '08' then sev = 'A06';
/*Permanent uarbejdsdygtighed eller uarbejdsdygtighed i 6 mneder eller derover*/
else if foel_e5 = '09' then sev = '997';
/*Dd*/
else if foel_e5 = '10' then sev = '998';

/***********************************************/
* Work station (arbejdsplads) - sknnet udfra
  oplysninger om ulykkessted (USTED);
* - Wst ($1);
/* Arbejdsplads uoplyst */
wst = '0';
/* Sdvanlig arbejdsplads / p virksomheden eller uoplyst */
if usted_e5 = '1' then wst = '1';
/* Mobil arbejdsplads eller andet uden for virksomheden   */
if usted_e5 in ('2', '3', '4', '5', '6', '7', '8', '9', '10') then wst = '2';
/* Anden arbejdsplads */
if usted_e5 in ('11', '98') then wst = '9'; 

/***********************************************/
* Working environment - phase 3
- Wen ($3.)
Omkodning af ulykkessted (USTED) til Work Environment (Wen);
wen = '000';
if usted_e5 = '2' then wen = '020'; /* Construction sites */
if usted_e5 = '3' then wen = '062'; /* Means of transport */
if usted_e5 = '4' then wen = '071'; /* Private homes */
if usted_e5 = '5' then wen = '093'; /* In the air on board aircraft */
if usted_e5 = '6' then wen = '111'; /* At sea on board any kind of vessel, platform */
if usted_e5 = '7' then wen = '111'; /* At sea on board any kind of vessel, platform */
if usted_e5 = '10' and aut = 'air' then wen = '093'; /* In the air - abroad */

/***********************************************/
* Working process - phase 3
- Wpr ($2.)
Omkodning af arbejdsproces (ARBP) til Work process;
*%inc omkod(arbp_wrkpr);
wpr = '00';

/***********************************************/
* Activity
- spa ($2.);
spa = '00';

/***********************************************/
* Material agent - activity
- ma_spa ($4.);
ma_spa = '0000';

/***********************************************/
* Deviation
- dev ($2.);
dev = afv2_e5;
if afv2_e5 = '76' then dev = '79';
if afv2_e5 in ('', '99') then dev = '00';
if afv2_e5 = '98' then dev = '99';

/***********************************************/
* Material agent - deviation
- ma_dev ($4.);
ma_dev = '0000';

/***********************************************/
* Contact/Mode of injury - phase 3
- cmi ($2.)
Omkodning af skademaade (SKMA) til Contact (CMI);
cmi = skma2_e5;
if skma2_e5 in ('', '00', '99') then cmi = '00';
if skma2_e5 = '98' then cmi = '99';

/***********************************************/
* Material agent/Contact - phase 3
- ma_cmi ($4)
Omkodning af kontaktteknik (TEKN) til Material agent corresponding to Contact (MA_CMI)
TEKN udget af registret pr. 17.06.2017;
ma_cmi = '0000';
/***********************************************/
* Road Trafic Accident  (trafikulykker) - ESAW WG 2012
  oplysninger om ulykkessted (USTED);
* - Rta ($1);
rta = 'N'; /* Trafikulykke: NEJ */
if usted_e5 = '3' and aut = 'wea' then rta = 'Y'; /* Trafikulykke: JA */
if usted_e5 = '3' and aut in ('dma', 'air') then rta = 'U'; /* Ikke transportulykker til ss og i luften */

/***********************************************/
* Weight - for underrapportering;
wgt = 1.86;
if foel_e5 = '10' then wgt = 1.0;
 
/***********************************************/
* Weight - phase 3;
wgt_p3 = 1.86;
if foel_e5 = '10' then wgt_p3 = 1.0;

/***********************************************/
keep case nace isco age sex inj body geo date time size nati
empst sev wst wen wpr spa ma_spa dev ma_dev cmi ma_cmi rta wgt wgt_p3;
run;
/***********************************************/
/*          P R O G R A M     E N D            */
/***********************************************/
DATA ACH.ESAW_DK_2021_v0001; SET ESAW_2021_DK; RUN;
/* EXPORT: Vlg Export data i menuen efter klik p SAS-datasttet */
/***********************************************/
/*              R E V I S I O N                */
/***********************************************/
DATA ACH.ESAW_DK_2021_v0002; SET ESAW_2021_DK; 
if case = 20210022749 then time = '99';
RUN;


DATA ACH.ESAW_AKKUM; SET ACH.ESAW_2017_DK ACH.ESAW_2018_DK; RUN;
/***********************************************/
/*          E K S P O R T     E N D            */
/***********************************************/

title 'ESAW data 2010 - DK, ach';
Proc contents data=esaw2010.esaw2010_DK;
run;

/* TABLES - TEST */
title1 'Table 1: Notified Accidents 2018';
title2 '         Severity of Injury / Sex';
%X2
(ACH.ESAW_DK_2021_v0001 (where=(sev= '998')), "Days lost" , "RTA", internal ,
sev, rta, $ , $ , 30.0 , 6.0 , 7.0 , noseps , 62 , 109);

title1 'Table 1: Notified Accidents 2020';
title2 '         Severity of Injury / rta';
%X2
(ACH.ESAW_DK_2020_v0001 (where=(sev= '998')), "WEN" , "RTA", internal ,
wen, rta, $ , $ , 30.0 , 6.0 , 7.0 , noseps , 62 , 109);

data fatal;
	set ACH.ESAW_DK_2021_v0002;
	if sev = '998';
run;

data ut; set ach.esaw_2021_br21;
nace = substr(br,1,4);
if foel_e5 = '10';
run;
%X2
(ut, "nace" , "RTA", internal ,
br21, usted_e5, $ , $ , 30.0 , 6.0 , 7.0 , noseps , 62 , 109);

%X2
(fatal, "nace" , "RTA", internal ,
nace, rta, $ , $ , 30.0 , 6.0 , 7.0 , noseps , 62 , 109);

title1 'Table 2: Notified Accidents 2018';
title2 '         Severity of Injury / Sex';
%X2
(ACH.ESAW_DK_2019_v0001, "Contact Mode" , "Year", internal ,
cmi, wen, $ , $ , 30.0 , 6.0 , 7.0 , noseps , 62 , 109);

data dead; set ESAW2013.ESAW2013_DK ; if sev = '998'; run;
title1 'Table 1: Notified Accidents 2013';
title2 '         Severity of Injury / Sex';
%X2
(ESAW2013.ESAW2013_DK, "Aut" , "RTA", internal ,
sex, rta, $ , $ , 30.0 , 6.0 , 7.0 , noseps , 62 , 109);

data esaw2011.death11; set esaw2011.ESAW2011_DK; if dayl = '998'; run;

/***********************************************/
/* NACE 2, hovedgrupper A - U                  */
/***********************************************/
data ach.esaw_2021_br21;
set ach.esaw_2021;
length br21 $1.;
/* A. Landbrug, jagt, skovbrug og fiskeri                  */
       if ('010000' <= br <= '039999') then br21 = 'A';

/* B. Rstofindvinding                                     */
  else if ('050000' <= br <= '099999') then br21 = 'B';

/* C. Fremstillingsvirksomhed                              */
  else if ('100000' <= br <= '339999') then br21 = 'C';

/* D. El-, gas- og fjernvarmefirsyning                     */
  else if ('350000' <= br <= '359999') then br21 = 'D';

/* E. Vandforsyning, kloakvsen, affaldshndtering mv.     */
  else if ('360000' <= br <= '399999') then br21 = 'E';

/* F. Bygge- og anlgsvirksomhed                           */
  else if ('410000' <= br <= '439999') then br21 = 'F';

/* G. Engros- og detailhandel, rep. af motorkr. og -cykler*/
  else if ('450000' <= br <= '479999') then br21 = 'G';

/* H. Transport og godshndtering                          */
  else if ('490000' <= br <= '539999') then br21 = 'H';

/* I. Overnatningsfaciliteter og restaurationsvirksomhed   */
  else if ('550000' <= br <= '569999') then br21 = 'I';

/* J. Information og kommunikation                         */
  else if ('580000' <= br <= '639999') then br21 = 'J';

/* K. Pengeinstitut- og finansvirksomhed mv.               */
  else if ('640000' <= br <= '669999') then br21 = 'K';

/* L. Fast ejendom                                         */
  else if ('680000' <= br <= '689999') then br21 = 'L';

/* M. Liberale, videnskabelige og tekniske tjenesteydelser */
  else if ('690000' <= br <= '759999') then br21 = 'M';

/* N. Administrative tjenesteydelser og hjlpetjenester    */
  else if ('770000' <= br <= '829999') then br21 = 'N';

/* O. Offentlig forvaltning og forsvar, socialsikring      */
  else if ('840000' <= br <= '849999') then br21 = 'O';

/* P. Undervisning                                         */
  else if ('850000' <= br <= '859999') then br21 = 'P';

/* Q. Sundhedsvsen og sociale foranstaltninger            */
  else if ('860000' <= br <= '889999') then br21 = 'Q';

/* R. Kultur, forlystelser og sport                        */
  else if ('900000' <= br <= '939999') then br21 = 'R';

/* S. Andre serviceydelser                                 */
  else if ('940000' <= br <= '969999') then br21 = 'S';

/* T. Private husholdninger med ansat medhjlp mv.         */
  else if ('970000' <= br <= '989999') then br21 = 'T';

/* U. Ekstraterritoriale organisationer og organer         */
  else if br = '990000'                then br21 = 'U';

/* X. Uoplyst                                              */
 else                                       br21 = 'X';
br2digit = substr(br,1,2);
if foel_e5 = '10';
run;
proc freq data = ach.esaw_2021_br21; table br21 /norow nocol nopercent; run;

title1 'UT 2013 - brancher';
%X3d
(esaw2013.esaw_br21, "Branchegrupper (21 grupper) / Brancher (2 cifre)", "Kn", 
internal, br21, br2digit, kqn, 
$, $, $, 32, 7., 8.,,50, 120);
data esaw2013.nace; set esaw2013.nace_2;
br2digit = substr(db07,1,2);
run;
title1 'UT 2013 - brancher';
%X1s
(esaw2013.nace, "Brancher (2 cifre)",  
internal, br2digit, antal, 
$, 32, 8.,,50, 120);


data NACE_12;
set esaw2012.ESAW_br21;
if br21 in ('A','C','D','E','F','G','H','I','J','K','L','M','N')
;
run;

data death12_trafic;
set esaw2012.ESAW_br21;
if br21 in ('A','C','D','E','F','G','H','I','J','K','L','M','N')
and foel = '10';
run;


title1 'Table 1e: Notified Fatal Accidents 2012';
title2 '          13 NACE branches / Type of Injury';
proc freq data = death12_trafic;
format usted $usted_t.;
table usted /nocol norow nopercent;
run;

/***********************************************/
/* Beskftigelsesdata - 2012                   */
/* Population omfattet af ESAW data            */
/***********************************************/
data esaw2012.besk12;
set be9data.ras0312;
if rgar4 = '2012';
length br21 $1.;
/* A. Landbrug, jagt, skovbrug og fiskeri                  */
       if ('010000' <= br <= '039999') then br21 = 'A';
/* B. Rstofindvinding                                     */
  else if ('050000' <= br <= '099999') then br21 = 'B';
/* C. Fremstillingsvirksomhed                              */
  else if ('100000' <= br <= '339999') then br21 = 'C';
/* D. El-, gas- og fjernvarmefirsyning                     */
  else if ('350000' <= br <= '359999') then br21 = 'D';
/* E. Vandforsyning, kloakvsen, affaldshndtering mv.     */
  else if ('360000' <= br <= '399999') then br21 = 'E';
/* F. Bygge- og anlgsvirksomhed                           */
  else if ('410000' <= br <= '439999') then br21 = 'F';
/* G. Engros- og detailhandel, rep. af motorkr. og -cykler*/
  else if ('450000' <= br <= '479999') then br21 = 'G';
/* H. Transport og godshndtering                          */
  else if ('490000' <= br <= '539999') then br21 = 'H';
/* I. Overnatningsfaciliteter og restaurationsvirksomhed   */
  else if ('550000' <= br <= '569999') then br21 = 'I';
/* J. Information og kommunikation                         */
  else if ('580000' <= br <= '639999') then br21 = 'J';
/* K. Pengeinstitut- og finansvirksomhed mv.               */
  else if ('640000' <= br <= '669999') then br21 = 'K';
/* L. Fast ejendom                                         */
  else if ('680000' <= br <= '689999') then br21 = 'L';
/* M. Liberale, videnskabelige og tekniske tjenesteydelser */
  else if ('690000' <= br <= '759999') then br21 = 'M';
/* N. Administrative tjenesteydelser og hjlpetjenester    */
  else if ('770000' <= br <= '829999') then br21 = 'N';
/* O. Offentlig forvaltning og forsvar, socialsikring      */
  else if ('840000' <= br <= '849999') then br21 = 'O';
/* P. Undervisning                                         */
  else if ('850000' <= br <= '859999') then br21 = 'P';
/* Q. Sundhedsvsen og sociale foranstaltninger            */
  else if ('860000' <= br <= '889999') then br21 = 'Q';
/* R. Kultur, forlystelser og sport                        */
  else if ('900000' <= br <= '939999') then br21 = 'R';
/* S. Andre serviceydelser                                 */
  else if ('940000' <= br <= '969999') then br21 = 'S';
/* T. Private husholdninger med ansat medhjlp mv.         */
  else if ('970000' <= br <= '989999') then br21 = 'T';
/* U. Ekstraterritoriale organisationer og organer         */
  else if br = '990000'                then br21 = 'U';
/* X. Uoplyst                                              */
 else                                       br21 = 'X';
run;

data esaw2012.empl2012; 
set esaw2012.besk12;
nace2 = substr(br,1,2);
run;
